@@ -22,13 +22,13 @@
 #include <KConfigGroup>
 #include <QDebug>
 
-#include <QtCore/QFileInfo>
+#include <QFileInfo>
 
 const Killbots::Ruleset *Killbots::Ruleset::load(const QString &fileName)
 {
     const Ruleset *result = 0;
     if (!fileName.isEmpty()) {
-        QString filePath = QStandardPaths::locate(QStandardPaths::GenericDataLocation, "killbots/rulesets/" + fileName);
+        QString filePath = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("killbots/rulesets/") + fileName);
         if (!filePath.isEmpty()) {
             // Our only check for validity is that we can open the file as a config
             // file and that it contains a group named "KillbotsRuleset".
@@ -50,7 +50,7 @@ Killbots::Ruleset::Ruleset(const QString &filePath)
 {
     m_filePath = filePath;
     QString untranslatedName = KConfigGroup(config(), "KillbotsRuleset").readEntryUntranslated("Name");
-    m_scoreGroupKey = untranslatedName.simplified().remove(' ').toLatin1();
+    m_scoreGroupKey = untranslatedName.simplified().remove(QLatin1Char(' ')).toLatin1();
 }
 
 Killbots::Ruleset::~Ruleset()
